@@ -239,13 +239,15 @@ gok_input_ext_devices_exist (void)
 static gboolean   
 gok_input_open (GokInput *input)
 {
-  GtkWidget *window = gok_main_get_main_window ();
-  if (input) 
-      input->open = FALSE;
+  GtkWidget *window;
 
-#ifdef HAVE_XINPUT  
+  g_return_val_if_fail (input != NULL, FALSE);
+  input->open = FALSE;
+
+#ifdef HAVE_XINPUT
+  window = gok_main_get_main_window ();
   if (window && window->window && 
-      input && input->info && (input->info->use == IsXExtensionDevice))
+      input->info && (input->info->use == IsXExtensionDevice))
     {
       gdk_error_trap_push ();
       input->device = XOpenDevice(GDK_WINDOW_XDISPLAY (window->window), 
@@ -254,9 +256,9 @@ gok_input_open (GokInput *input)
 	  input->open = TRUE;
     }
 #endif
-  if (!input && !input->open)
-    g_warning ("could not open device %s", input);
-  
+  if (input->name && !input->open)
+    g_warning ("could not open device %s", input->name);
+
   return input->open;
 }
 
